'use strict';

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _tape = require('tape');

var _tape2 = _interopRequireDefault(_tape);

var _index = require('../index');

var _index2 = _interopRequireDefault(_index);

var _remark = require('remark');

var _remark2 = _interopRequireDefault(_remark);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var MAXWEIGHT = '#';
var MINWEIGHT = '######';

(0, _tape2.default)('Add heading weight', function (test) {
  var expected = '# Heading\n';
  var actual = _remark2.default.use(_index2.default, { weight: 1 }).process('## Heading');

  test.equal(actual, expected);
  test.end();
});

(0, _tape2.default)('Remove heading weight', function (test) {
  var expected = '## Heading\n';
  var actual = _remark2.default.use(_index2.default, { weight: -1 }).process('# Heading');

  test.equal(actual, expected);
  test.end();
});

(0, _tape2.default)('Add max heading weight', function (test) {
  var expected = MAXWEIGHT + ' Heading\n';
  var actual = _remark2.default.use(_index2.default, { weight: 10 }).process('## Heading');

  test.equal(actual, expected);
  test.end();
});

(0, _tape2.default)('Remove max heading weight', function (test) {
  var expected = MINWEIGHT + ' Heading\n';
  var actual = _remark2.default.use(_index2.default, { weight: -10 }).process('## Heading');

  test.equal(actual, expected);
  test.end();
});

(0, _tape2.default)('Remove max heading w/o preserve', function (test) {
  var expected = ' Heading\n';
  var actual = _remark2.default.use(_index2.default, { weight: -10, preserve: false }).process('## Heading');

  test.equal(actual, expected);
  test.end();
});

(0, _tape2.default)('Add heading weight after', function (test) {
  var expected = '## Heading 1\n\n## Heading 2\n';
  var actual = _remark2.default.use(_index2.default, { weight: -1, after: '## Heading 1' }).process('## Heading 1\n# Heading 2');

  test.equal(actual, expected);
  test.end();
});

(0, _tape2.default)('Remove heading weight after', function (test) {
  var expected = '## Heading 1\n\n# Heading 2\n';
  var actual = _remark2.default.use(_index2.default, { weight: 1, after: '## Heading 1' }).process('## Heading 1\n## Heading 2');

  test.equal(actual, expected);
  test.end();
});

(0, _tape2.default)('Add max heading weight after', function (test) {
  var expected = '## Heading 1\n\n' + MAXWEIGHT + ' Heading 2\n';
  var actual = _remark2.default.use(_index2.default, { weight: 10, after: '## Heading 1' }).process('## Heading 1\n## Heading 2');

  test.equal(actual, expected);
  test.end();
});

(0, _tape2.default)('Remove max heading weight after', function (test) {
  var expected = '## Heading 1\n\n' + MINWEIGHT + ' Heading 2\n';
  var actual = _remark2.default.use(_index2.default, { weight: -10, after: '## Heading 1' }).process('## Heading 1\n## Heading 2');

  test.equal(actual, expected);
  test.end();
});

(0, _tape2.default)('Remove max heading weight w/o preserve after', function (test) {
  var expected = '## Heading 1\n\n Heading 2\n';
  var actual = _remark2.default.use(_index2.default, { weight: -10, after: '## Heading 1', preserve: false }).process('## Heading 1\n## Heading 2');

  test.equal(actual, expected);
  test.end();
});

(0, _tape2.default)('Add heading weight before', function (test) {
  var expected = '### Heading 1\n\n## Heading 2\n';
  var actual = _remark2.default.use(_index2.default, { weight: -1, before: '## Heading 2' }).process('## Heading 1\n## Heading 2');

  test.equal(actual, expected);
  test.end();
});

(0, _tape2.default)('Remove heading weight before', function (test) {
  var expected = '# Heading 1\n\n## Heading 2\n';
  var actual = _remark2.default.use(_index2.default, { weight: 1, before: '## Heading 2' }).process('## Heading 1\n## Heading 2');

  test.equal(actual, expected);
  test.end();
});

(0, _tape2.default)('Add max heading weight before', function (test) {
  var expected = MAXWEIGHT + ' Heading 1\n\n## Heading 2\n';
  var actual = _remark2.default.use(_index2.default, { weight: 10, before: '## Heading 2' }).process('## Heading 1\n## Heading 2');

  test.equal(actual, expected);
  test.end();
});

(0, _tape2.default)('Remove max heading weight before', function (test) {
  var expected = MINWEIGHT + ' Heading 1\n\n## Heading 2\n';
  var actual = _remark2.default.use(_index2.default, { weight: -10, before: '## Heading 2' }).process('## Heading 1\n## Heading 2');

  test.equal(actual, expected);
  test.end();
});

(0, _tape2.default)('Remove max heading weight w/o preserve before', function (test) {
  var expected = ' Heading 1\n\n## Heading 2\n';
  var actual = _remark2.default.use(_index2.default, { weight: -10, before: '## Heading 2', preserve: false }).process('## Heading 1\n## Heading 2');

  test.equal(actual, expected);
  test.end();
});

(0, _tape2.default)('Add heading weight between', function (test) {
  var expected = '## Heading 1\n\n### Heading 2\n\n## Heading 3\n';
  var actual = _remark2.default.use(_index2.default, { weight: -1, between: ['## Heading 1', '## Heading 3'] }).process('## Heading 1\n## Heading 2\n## Heading 3');

  test.equal(actual, expected);
  test.end();
});

(0, _tape2.default)('Remove heading weight between', function (test) {
  var expected = '## Heading 1\n\n# Heading 2\n\n## Heading 3\n';
  var actual = _remark2.default.use(_index2.default, { weight: 1, between: ['## Heading 1', '## Heading 3'] }).process('## Heading 1\n## Heading 2\n## Heading 3');

  test.equal(actual, expected);
  test.end();
});

(0, _tape2.default)('Add max heading weight between', function (test) {
  var expected = '## Heading 1\n\n' + MAXWEIGHT + ' Heading 2\n\n## Heading 3\n';
  var actual = _remark2.default.use(_index2.default, { weight: 10, between: ['## Heading 1', '## Heading 3'] }).process('## Heading 1\n## Heading 2\n## Heading 3');

  test.equal(actual, expected);
  test.end();
});

(0, _tape2.default)('Remove max heading weight between', function (test) {
  var expected = '## Heading 1\n\n' + MINWEIGHT + ' Heading 2\n\n## Heading 3\n';
  var actual = _remark2.default.use(_index2.default, { weight: -10, between: ['## Heading 1', '## Heading 3'] }).process('## Heading 1\n## Heading 2\n## Heading 3');

  test.equal(actual, expected);
  test.end();
});

(0, _tape2.default)('Remove max heading weight w/o preserve between', function (test) {
  var expected = '## Heading 1\n\n Heading 2\n\n## Heading 3\n';
  var actual = _remark2.default.use(_index2.default, { weight: -10, between: ['## Heading 1', '## Heading 3'], preserve: false }).process('## Heading 1\n## Heading 2\n## Heading 3');

  test.equal(actual, expected);
  test.end();
});